@@ -2,16 +2,15 @@ package Web::Components::Role::TT;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
-use Class::Usul::Constants  qw( EXCEPTION_CLASS NUL TRUE );
-use Class::Usul::Functions  qw( throw );
-use File::DataClass::Types  qw( Directory Object );
+use File::DataClass::Constants qw( EXCEPTION_CLASS NUL TRUE );
+use File::DataClass::Types     qw( Directory Object );
 use Template;
-use Unexpected::Functions   qw( PathNotFound );
+use Unexpected::Functions      qw( PathNotFound throw );
 use Moo::Role;
 
-requires qw( config );
+requires qw( config ); # layout root skin tempdir
 
 # Attribute constructors
 my $_build__templater = sub {
@@ -63,13 +62,12 @@ __END__
 
 =head1 Name
 
-Web::Components::Role::TT - Applies Template as Web::Component role
+Web::Components::Role::TT - Applies Template as a Moo::Role
 
 =head1 Synopsis
 
    use Moo;
 
-   with 'Web::Components::Role';
    with 'Web::Components::Role::TT';
 
    $rendered_template = $self->render_template( $stash );
@@ -93,6 +91,10 @@ Defines the following attributes;
 A lazily evaluated directory which defaults to F<templates> in the configuration
 root directory. This is where the templates are stored
 
+The path to the template file is F<< templates/<skin>/<layout>.tt >>. The
+C<skin> and C<layout> attributes default to the values of the configuration
+object
+
 =back
 
 =head1 Subroutines/Methods
@@ -106,10 +108,6 @@ invocant is expected to provide a C<config> object. The C<$stash> should also
 contain C<skin> and C<page> attributes. The C<page> hash reference should
 contain a C<layout> attribute
 
-The path to the template file is F<< templates/<skin>/<layout>.tt >>. The
-C<skin> and C<layout> attributes default to the values of the configuration
-object
-
 =head1 Diagnostics
 
 The compiled templates are stored in subdirectories below the configuration
@@ -119,8 +117,6 @@ temporary directory
 
 =over 3
 
-=item L<Class::Usul>
-
 =item L<File::DataClass>
 
 =item L<Moo>
